@@ -1,7 +1,7 @@
 #!/bin/sh
 # Simple and straight forward openssl cert generator for ircd-ratbox
-# Copyright (C) 2008-2011 ircd-ratbox development team
-# $Id: genssl.sh 27249 2011-10-21 00:06:19Z dubkat $
+# Copyright (C) 2008-2012 ircd-ratbox development team
+# $Id: genssl.sh 29251 2015-12-18 17:15:54Z androsyn $
 
 if [ $# -eq 0 ]; then
 	echo
@@ -20,12 +20,12 @@ if [ "$DAYS_VALID" -gt "365" ]; then
 fi
 
 echo
-echo "Generating 1024-bit self-signed RSA key for ${SERVER}... "
-openssl req -new -newkey rsa:1024 -days ${SSL_DAYS_VALID} -nodes -x509 -keyout ${SERVER}.pem  -out ${SERVER}.pem
+echo "Generating 2048-bit self-signed RSA key for ${SERVER}... "
+openssl req -new -newkey rsa:2048 -sha256 -days ${SSL_DAYS_VALID} -nodes -x509 -keyout ${SERVER}.pem  -out ${SERVER}.pem
 echo "Done creating self-signed cert"
 
 echo -n "Generating DH parameters file... "
-openssl dhparam -out dh.pem 1024
+openssl dhparam -out dh.pem 2048
 echo "Done."
 
 echo
